@@ -95,8 +95,9 @@ class SilaClient:
         self.__port = port
 
         target = f"{self.__address}:{self.__port}"
+
         expected_server_uuid: Optional[UUID] = None
-        if any(par is not None for par in (root_certs, private_key, cert_chain)):
+        if root_certs is not None or private_key is not None or cert_chain is not None:
             if insecure:
                 raise ValueError("Cannot use certificate information with insecure connections")
 
@@ -116,7 +117,8 @@ class SilaClient:
         elif insecure:
             self._channel = grpc.insecure_channel(target)
         else:
-            raise ValueError("Either use an insecure connection, or provide certificate information")
+            # use default trust store
+            self._channel = grpc.secure_channel(target, credentials=grpc.ssl_channel_credentials())
 
         self._features = {}
         self._children_by_fully_qualified_identifier = {}
