@@ -71,3 +71,11 @@ def call_rpc_function(
                     )
             raise sila_err  # plain defined execution error, undefined execution error, validation or framework error
         raise SilaConnectionError.from_exception(ex)  # server didn't send a SiLA error -> connection error
+
+
+def is_channel_connected(channel: grpc.Channel, timeout: int = 1) -> bool:
+    try:
+        grpc.channel_ready_future(channel).result(timeout=timeout)
+    except TimeoutError:
+        return False
+    return True
