@@ -8,7 +8,6 @@ from typing import Dict, List
 
 from typer import Argument, Option, Typer
 
-from sila2.framework import FullyQualifiedFeatureIdentifier
 from sila2.framework.utils import parse_feature_definition, xpath_sila
 
 main = Typer(help="SiLA 2 Python Code Generator")
@@ -152,7 +151,6 @@ def update_package(
         generated_dir = find_matching_directory(join(package_directory, "*", "generated"))
         implementation_dir = find_matching_directory(join(package_directory, "*", "feature_implementations"))
 
-        features: Dict[FullyQualifiedFeatureIdentifier, Feature] = {}
         generator = CodeGenerator(overwrite=True)
 
         # give precedence to explicitly stated features
@@ -163,10 +161,11 @@ def update_package(
             get_identifier(f): f for f in glob(join(generated_dir, "*", "*.sila.xml"))
         }
         fdl_files_by_identifier.update({get_identifier(f): f for f in feature_definitions})
-        print(fdl_files_by_identifier)
 
+        features: List[Feature] = []
         for fdl_file in fdl_files_by_identifier.values():
             feature = Feature(fdl_file)
+            features.append(feature)
             feature_generator = FeatureGenerator(feature, overwrite=True)
             feature_dir = join(generated_dir, feature._identifier.lower())
             with open(f"{feature_dir}/{feature._identifier.lower()}_base.py") as fp:
@@ -180,7 +179,7 @@ def update_package(
             if old_base != new_base:
                 feature_generator.generate_impl(implementation_dir, prefix="updated_")
             generator.generated_files.extend(feature_generator.generated_files)
-        generator._generate_client(features.values(), generated_dir)
+        generator._generate_client(features, generated_dir)
         generator.format_generated_files()
 
 
