@@ -88,7 +88,7 @@ class SilaServiceListener(ServiceListener):
                         RuntimeWarning(
                             f"Detected server at {ip_address}:{port} with UUID {service_uuid}, "
                             f"but found no way to connect to it "
-                            f"(insecure connections are disabled, no certificate information privided)"
+                            f"(insecure connections are disabled, no certificate information provided)"
                         )
                     )
         except Exception as ex:
@@ -101,14 +101,20 @@ class SilaServiceListener(ServiceListener):
 
     @staticmethod
     def __get_ca_from_service_info(service_info: ServiceInfo) -> Optional[bytes]:
-        if b"ca0" not in service_info.properties:
+        # implementation note: the correct key format is 'ca<i>', where i starts with 0.
+        # For backwards-compatibility with a bug in previous versions, the format 'cai' is also recognized.
+        txt_records = service_info.properties
+        if b"ca0" not in txt_records:
             return None
 
         ca = b""
         for i in itertools.count():
             key = f"ca{i}".encode("ascii")
-            if key in service_info.properties:
-                ca += service_info.properties[key]
+            if key in txt_records:
+                cert_line: bytes = txt_records[key]
+                if not cert_line.endswith((b"\n", b"\r")):
+                    cert_line += b"\n"
+                ca += cert_line
             else:
                 break
         if ca == b"":
