@@ -14,8 +14,8 @@ _pb2_module, _ = run_protoc(join(resource_dir, "proto", "SiLAFramework.proto"))
 
 if TYPE_CHECKING:
     from sila2.client.sila_client import SilaClient
-    from sila2.pb2_stubs import SiLAFramework_pb2
-    from sila2.pb2_stubs.SiLAFramework_pb2 import SiLAError
+    from sila2.framework.pb2 import SiLAFramework_pb2
+    from sila2.framework.pb2.SiLAFramework_pb2 import SiLAError
 
     _pb2_module = SiLAFramework_pb2
 
