@@ -14,7 +14,7 @@ from sila2.framework.binary_transfer.invalid_binary_transfer_uuid import Invalid
 from sila2.framework.binary_transfer.upload_servicer import BinaryUploadServicer
 
 if TYPE_CHECKING:
-    from sila2.pb2_stubs.SiLAFramework_pb2 import Binary as SilaBinary
+    from sila2.framework.pb2.SiLAFramework_pb2 import Binary as SilaBinary
 
 
 class ServerBinaryTransferHandler(BinaryTransferHandler):
