@@ -16,7 +16,7 @@ from sila2.framework.utils import raise_as_rpc_error
 
 if TYPE_CHECKING:
     from sila2.framework.binary_transfer.server_binary_transfer_handler import ServerBinaryTransferHandler
-    from sila2.pb2_stubs import SiLABinaryTransfer_pb2
+    from sila2.framework.pb2 import SiLABinaryTransfer_pb2
 
 
 class BinaryUploadServicer(binary_transfer_grpc_module.BinaryUploadServicer):
