@@ -7,7 +7,7 @@ from sila2.framework.abc.named_node import NamedNode
 from sila2.framework.command.parameter import Parameter
 from sila2.framework.command.response import Response
 from sila2.framework.defined_execution_error_node import DefinedExecutionErrorNode
-from sila2.framework.fully_qualified_identifier import FullyQualifiedIdentifier
+from sila2.framework.fully_qualified_identifier import FullyQualifiedCommandIdentifier
 from sila2.framework.utils import xpath_sila
 
 if TYPE_CHECKING:
@@ -17,7 +17,7 @@ if TYPE_CHECKING:
 class Command(NamedNode):
     """Represents a command"""
 
-    fully_qualified_identifier: FullyQualifiedIdentifier
+    fully_qualified_identifier: FullyQualifiedCommandIdentifier
     """Fully qualified command identifier"""
     parent_feature: Feature
     parameters: CompositeMessageMappable[Parameter]
@@ -27,7 +27,7 @@ class Command(NamedNode):
     def __init__(self, fdl_node, parent_feature: Feature):
         super().__init__(fdl_node)
         self.parent_feature = parent_feature
-        self.fully_qualified_identifier = FullyQualifiedIdentifier(
+        self.fully_qualified_identifier = FullyQualifiedCommandIdentifier(
             f"{parent_feature.fully_qualified_identifier}/Command/{self._identifier}"
         )
         self.parameters = CompositeMessageMappable(
