@@ -12,13 +12,12 @@ if TYPE_CHECKING:
 
 
 class FullyQualifiedIdentifier(Constraint[str]):
-    id_type: str
-
     def __init__(self, id_type: str):
         self.id_type = id_type
+        self.check_regex = getattr(FullyQualifiedIdentifierRegex, id_type)
 
     def validate(self, value: str) -> bool:
-        return bool(re.match(f"^{getattr(FullyQualifiedIdentifierRegex, self.id_type)}$", value))
+        return bool(re.match(f"^{self.check_regex}$", value))
 
     @classmethod
     def from_fdl_node(cls, fdl_node, parent_feature: Feature, base_type: DataType) -> FullyQualifiedIdentifier:
