@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Union
+from typing import TYPE_CHECKING, TypeVar, Union
 
 from sila2.framework.abc.constraint import Constraint
 
@@ -9,7 +9,10 @@ if TYPE_CHECKING:
     from sila2.framework.feature import Feature
 
 
-class Length(Constraint):
+T = TypeVar("T", bound=Union[str, bytes])
+
+
+class Length(Constraint[T]):
     length: int
 
     def __init__(self, length: int):
@@ -19,7 +22,7 @@ class Length(Constraint):
             raise ValueError("Length cannot be greater than 2^63 - 1")
         self.length = length
 
-    def validate(self, value: Union[str, bytes]) -> bool:
+    def validate(self, value: T) -> bool:
         return len(value) == self.length
 
     @classmethod
