@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Union
+from typing import TYPE_CHECKING, TypeVar, Union
 
 from sila2.framework.abc.constraint import Constraint
 
@@ -9,6 +9,9 @@ if TYPE_CHECKING:
     from sila2.framework.feature import Feature
 
 
+T = TypeVar("T", bound=Union[str, bytes])
+
+
 class MinimalLength(Constraint):
     min_length: int
 
