@@ -10,7 +10,7 @@ if TYPE_CHECKING:
     from sila2.framework.feature import Feature
 
 
-class Pattern(Constraint):
+class Pattern(Constraint[str]):
     pattern: str
 
     def __init__(self, pattern: str):
