@@ -6,7 +6,7 @@ from google.protobuf.message import Message
 
 from sila2.framework.abc.named_data_node import NamedDataNode
 from sila2.framework.defined_execution_error_node import DefinedExecutionErrorNode
-from sila2.framework.fully_qualified_identifier import FullyQualifiedIdentifier
+from sila2.framework.fully_qualified_identifier import FullyQualifiedPropertyIdentifier
 from sila2.framework.utils import xpath_sila
 
 if TYPE_CHECKING:
@@ -16,7 +16,7 @@ if TYPE_CHECKING:
 class Property(NamedDataNode):
     """Represents a property"""
 
-    fully_qualified_identifier: FullyQualifiedIdentifier
+    fully_qualified_identifier: FullyQualifiedPropertyIdentifier
     """Fully qualified property identifier"""
     parent_feature: Feature
     parameter_message_type: Type[Message]
@@ -31,7 +31,7 @@ class Property(NamedDataNode):
             fdl_node, parent_feature, getattr(parent_feature._pb2_module, f"{message_prefix}{identifier}_Responses")
         )
         self.parent_feature = parent_feature
-        self.fully_qualified_identifier = FullyQualifiedIdentifier(
+        self.fully_qualified_identifier = FullyQualifiedPropertyIdentifier(
             f"{parent_feature.fully_qualified_identifier}/Property/{self._identifier}"
         )
         self.defined_execution_errors = [
