@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Generic, TypeVar
 
 from sila2.framework.property.property import Property
 
@@ -8,7 +8,10 @@ if TYPE_CHECKING:
     from sila2.framework.feature import Feature
 
 
-class UnobservableProperty(Property):
+PythonType = TypeVar("PythonType")
+
+
+class UnobservableProperty(Property, Generic[PythonType]):
     """Represents an unobservable property"""
 
     def __init__(self, fdl_node, parent_feature: Feature):
