@@ -214,3 +214,18 @@ def resolve_host_to_ip_addresses(host: str) -> List[str]:
             return [socket.gethostbyname(host)]
         except socket.gaierror as e:
             raise ValueError(f"Failed to resolve host '{host}': {e.strerror}")
+
+
+def running_in_docker() -> bool:
+    if os.path.exists("/.dockerenv"):
+        return True
+
+    cgroup_file = "/proc/self/cgroup"
+    if not os.path.isfile(cgroup_file):
+        return False
+
+    with open(cgroup_file) as cgroup_fp:
+        for line in cgroup_fp:
+            if ":/docker/" in line:
+                return True
+    return False
