@@ -1,4 +1,4 @@
-from typing import Any, Dict
+from typing import Dict
 from uuid import UUID
 
 from sila2.features.authorizationproviderservice import (
@@ -10,6 +10,7 @@ from sila2.features.authorizationproviderservice import (
 from sila2.framework import FullyQualifiedIdentifier
 from sila2.server import SilaServer
 from sila2.server.default_feature_implementations.authenticationservice_impl import AccessToken
+from sila2.server.metadata_dict import MetadataDict
 
 
 class AuthorizationProviderServiceImpl(AuthorizationProviderServiceBase):
@@ -21,12 +22,7 @@ class AuthorizationProviderServiceImpl(AuthorizationProviderServiceBase):
         self.tokens = parent_server.feature_servicers["AuthenticationService"].implementation.active_tokens
 
     def Verify(
-        self,
-        AccessToken: str,
-        RequestedServer: str,
-        RequestedFeature: str,
-        *,
-        metadata: Dict[FullyQualifiedIdentifier, Any]
+        self, AccessToken: str, RequestedServer: str, RequestedFeature: str, *, metadata: MetadataDict
     ) -> Verify_Responses:
         try:
             token = self.tokens[UUID(AccessToken)]
