@@ -8,8 +8,10 @@ from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives.asymmetric import rsa
 from cryptography.x509 import NameAttribute, NameOID
 
+from sila2.framework.utils import resolve_host_to_ip_addresses
 
-def generate_self_signed_certificate(server_uuid: UUID, address: str) -> Tuple[bytes, bytes]:
+
+def generate_self_signed_certificate(server_uuid: UUID, host: str) -> Tuple[bytes, bytes]:
     private_key = rsa.generate_private_key(public_exponent=65537, key_size=2048)
 
     issuer = subject = get_sila_consortium_x509_name()
@@ -46,7 +48,7 @@ def generate_self_signed_certificate(server_uuid: UUID, address: str) -> Tuple[b
             critical=True,
         )
         .add_extension(
-            x509.SubjectAlternativeName([x509.IPAddress(IPv4Address(address))]),
+            x509.SubjectAlternativeName([x509.IPAddress(IPv4Address(h)) for h in resolve_host_to_ip_addresses(host)]),
             critical=False,
         )
         .add_extension(
