@@ -52,8 +52,8 @@ class SilaServer:
     server_vendor_url: str
     """SiLA Server Vendor URL"""
 
-    service_broadcaster: SilaServiceBroadcaster
-    running_instances: List[SilaServiceInfo]
+    __service_broadcaster: SilaServiceBroadcaster
+    __running_instances: List[SilaServiceInfo]
 
     binary_transfer_handler: ServerBinaryTransferHandler
 
@@ -176,8 +176,8 @@ class SilaServer:
         self.grpc_server = grpc.server(
             ThreadPoolExecutor(max_workers=max_grpc_workers, thread_name_prefix=f"grpc-executor-{self.server_uuid}")
         )
-        self.service_broadcaster = SilaServiceBroadcaster()
-        self.running_instances = []
+        self.__service_broadcaster = SilaServiceBroadcaster()
+        self.__running_instances = []
         self.features = {}
         self.feature_servicers = {}
         self.metadata_interceptors = []
@@ -299,9 +299,10 @@ class SilaServer:
             if ca_for_discovery is None and self.generated_ca is not None:
                 ca_for_discovery = self.generated_ca
 
-            info = self.service_broadcaster.register_server(self, address, port, ca=ca_for_discovery)
-            self.running_instances.append(info)
+            info = self.__service_broadcaster.register_server(self, address, port, ca=ca_for_discovery)
+            self.__running_instances.append(info)
 
+        self.logger.info("Server started")
         self.__is_running = True
         self.__was_started = True
 
@@ -379,23 +380,43 @@ class SilaServer:
             enable_discovery=enable_discovery,
         )
 
-    def stop(self, grace_period: Optional[float] = None):
+    def stop(self, grace_period: Optional[float] = None) -> None:
+        """
+        Stop the server and block until completion
+
+        Parameters
+        ----------
+        grace_period: Time in seconds to wait before aborting all ongoing interactions
+        """
+        self.logger.info("Stopping server...")
+        if not self.__is_running:
+            raise RuntimeError("Can only stop running servers")
+
         # stop zeroconf broadcasting
-        for info in self.running_instances:
-            self.service_broadcaster.unregister_server(info)
-            self.running_instances.remove(info)
+        self.logger.debug("Stopping zeroconf broadcasting")
+        for info in self.__running_instances:
+            self.__service_broadcaster.unregister_server(info)
+            self.__running_instances.remove(info)
 
         # stop feature implementations
+        self.logger.debug("Stopping feature implementation servicers")
         for servicer in self.feature_servicers.values():
             servicer.cancel_all_subscriptions()
             servicer.implementation.stop()
         self.child_task_executor.shutdown(wait=True)
 
         # stop grpc server
+        self.logger.debug("Stopping gRPC server")
         self.grpc_server.stop(grace_period).wait()
+        self.logger.info("Stopped server")
 
         self.__is_running = False
 
+    @property
+    def running(self) -> bool:
+        """True if the server is running, False otherwise"""
+        return self.__is_running
+
     def __getitem__(self, item: str) -> Feature:
         return self.features[item]
 
